@@ -322,8 +322,8 @@ Multiview = function( pathIn          = "./",
 CCM = function( pathIn          = "./",
                 dataFile        = "",
                 dataFrame       = NULL,
-                pathOut         = "./",
-                predictFile     = "",
+                # pathOut         = "./", # Rcpp 20 param limit
+                # predictFile     = "",   # Rcpp 20 param limit
                 E               = 0, 
                 Tp              = 0,
                 knn             = 0,
@@ -336,6 +336,7 @@ CCM = function( pathIn          = "./",
                 random          = TRUE,
                 replacement     = FALSE,
                 seed            = 0,
+                embedded        = FALSE,
                 includeData     = FALSE,
                 parameterList   = FALSE,
                 verbose         = FALSE,
@@ -365,8 +366,8 @@ CCM = function( pathIn          = "./",
   CCMList = RtoCpp_CCM( pathIn,
                         dataFile,
                         dataFrame,
-                        pathOut,
-                        predictFile,
+                        # pathOut,     # Rcpp 20 param limit
+                        # predictFile, # Rcpp 20 param limit
                         E, 
                         Tp,
                         knn,
@@ -379,6 +380,7 @@ CCM = function( pathIn          = "./",
                         random,
                         replacement,
                         seed,
+                        embedded,
                         includeData,
                         parameterList,
                         verbose )
