@@ -36,7 +36,7 @@ DataFrame< double > Embed( DataFrame< double > & dataFrame,
 DataFrame< double > MakeBlock( DataFrame< double >      & dataFrame,
                                int                      E,
                                int                      tau,
-                               std::vector<std::string> columnNames,
+                               std::vector<std::string> columns,
                                bool                     deletePartial = false );
 
 SimplexValues Simplex( std::string pathIn          = "./data/",
@@ -50,8 +50,8 @@ SimplexValues Simplex( std::string pathIn          = "./data/",
                        int         knn             = 0,
                        int         tau             = -1,
                        int         exclusionRadius = 0,
-                       std::string colNames        = "",
-                       std::string targetName      = "",
+                       std::string columns         = "",
+                       std::string target          = "",
                        bool        embedded        = false,
                        bool        const_predict   = false,
                        bool        verbose         = true,
@@ -69,8 +69,8 @@ SimplexValues Simplex( DataFrame< double > & dataFrameIn,
                        int         knn             = 0,
                        int         tau             = -1,
                        int         exclusionRadius = 0,
-                       std::string colNames        = "",
-                       std::string targetName      = "",
+                       std::string columns         = "",
+                       std::string target          = "",
                        bool        embedded        = false,
                        bool        const_predict   = false,
                        bool        verbose         = true,
@@ -191,13 +191,14 @@ CCMValues CCM( std::string pathIn          = "./data/",
                int         knn             = 0,
                int         tau             = -1,
                int         exclusionRadius = 0,
-               std::string colNames        = "",
-               std::string targetName      = "",
+               std::string columns         = "",
+               std::string target          = "",
                std::string libSizes_str    = "",
                int         sample          = 0,
                bool        random          = true,
                bool        replacement     = false,
                unsigned    seed            = 0,     // seed=0: use RNG
+               bool        embedded        = false,
                bool        includeData     = false,
                bool        parameterList   = false,
                bool        verbose         = true );
@@ -210,13 +211,14 @@ CCMValues CCM( DataFrame< double > & dataFrameIn,
                int         knn             = 0,
                int         tau             = -1,
                int         exclusionRadius = 0,
-               std::string colNames        = "",
-               std::string targetName      = "",
+               std::string columns         = "",
+               std::string target          = "",
                std::string libSizes_str    = "",
                int         sample          = 0,
                bool        random          = true,
                bool        replacement     = false,
                unsigned    seed            = 0, // seed=0: use RNG
+               bool        embedded        = false,
                bool        includeData     = false,
                bool        parameterList   = false,
                bool        verbose         = true );
@@ -272,8 +274,8 @@ DataFrame< double > EmbedDimension( std::string pathIn          = "./data/",
                                     int         Tp              = 1,
                                     int         tau             = -1,
                                     int         exclusionRadius = 0,
-                                    std::string colNames        = "",
-                                    std::string targetName      = "",
+                                    std::string columns         = "",
+                                    std::string target          = "",
                                     bool        embedded        = false,
                                     bool        verbose         = true,
                                     std::vector<bool> validLib  =
@@ -289,8 +291,8 @@ DataFrame< double > EmbedDimension( DataFrame< double > & dataFrameIn,
                                     int         Tp              = 1,
                                     int         tau             = -1,
                                     int         exclusionRadius = 0,
-                                    std::string colNames        = "",
-                                    std::string targetName      = "",
+                                    std::string columns         = "",
+                                    std::string target          = "",
                                     bool        embedded        = false,
                                     bool        verbose         = true,
                                     std::vector<bool> validLib  =
@@ -307,8 +309,8 @@ DataFrame< double > PredictInterval( std::string pathIn          = "./data/",
                                      int         E               = 0,
                                      int         tau             = -1,
                                      int         exclusionRadius = 0,
-                                     std::string colNames        = "",
-                                     std::string targetName      = "",
+                                     std::string columns         = "",
+                                     std::string target          = "",
                                      bool        embedded        = false,
                                      bool        verbose         = true,
                                      std::vector<bool> validLib  =
@@ -325,7 +327,7 @@ DataFrame< double > PredictInterval( DataFrame< double > & dataFrameIn,
                                      int         tau             = -1,
                                      int         exclusionRadius = 0,
                                      std::string colNames        = "",
-                                     std::string targetName      = "",
+                                     std::string target          = "",
                                      bool        embedded        = false,
                                      bool        verbose         = true,
                                      std::vector<bool> validLib  =
@@ -344,8 +346,8 @@ DataFrame< double > PredictNonlinear( std::string pathIn          = "./data/",
                                       int         knn             = 0,
                                       int         tau             = -1,
                                       int         exclusionRadius = 0,
-                                      std::string colNames        = "",
-                                      std::string targetName      = "",
+                                      std::string columns         = "",
+                                      std::string target          = "",
                                       bool        embedded        = false,
                                       bool        verbose         = true,
                                       std::vector<bool> validLib  =
@@ -363,8 +365,8 @@ DataFrame< double > PredictNonlinear( DataFrame< double > & dataFrameIn,
                                       int         knn             = 0,
                                       int         tau             = -1,
                                       int         exclusionRadius = 0,
-                                      std::string colNames        = "",
-                                      std::string targetName      = "",
+                                      std::string columns         = "",
+                                      std::string target          = "",
                                       bool        embedded        = false,
                                       bool        verbose         = true,
                                       std::vector<bool> validLib  =
